using System;
using System.Collections.Generic;
using Cpp2IlInjected;
using MEC;
using UnityEngine;
using UnityEngine.UI;

// Token: 0x020002C4 RID: 708
[Token(Token = "0x20002C4")]
public class UINavigationEffect : MonoBehaviour
{
	// Token: 0x17000114 RID: 276
	// (get) Token: 0x06001AAE RID: 6830 RVA: 0x000414A8 File Offset: 0x0003F6A8
	[Token(Token = "0x17000114")]
	public RectTransform Root
	{
		[Token(Token = "0x6001AAE")]
		[Address(RVA = "0x2EF530", Offset = "0x2EE530", VA = "0x1802EF530")]
		get
		{
			return this.root;
		}
	}

	// Token: 0x06001AAF RID: 6831 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001AAF")]
	[Address(RVA = "0xE7B2B0", Offset = "0xE7A2B0", VA = "0x180E7B2B0")]
	public void Appear()
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001AB0 RID: 6832 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001AB0")]
	[Address(RVA = "0xE7B4C0", Offset = "0xE7A4C0", VA = "0x180E7B4C0")]
	public void Hide()
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001AB1 RID: 6833 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001AB1")]
	[Address(RVA = "0xE7B370", Offset = "0xE7A370", VA = "0x180E7B370")]
	public void HideImmediate()
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001AB2 RID: 6834 RVA: 0x000414BC File Offset: 0x0003F6BC
	[Token(Token = "0x6001AB2")]
	[Address(RVA = "0xE6E260", Offset = "0xE6D260", VA = "0x180E6E260")]
	public void UpdateParent(Transform parent)
	{
		this.root.parentInternal = parent;
	}

	// Token: 0x06001AB3 RID: 6835 RVA: 0x000414DC File Offset: 0x0003F6DC
	[Token(Token = "0x6001AB3")]
	[Address(RVA = "0xE7B990", Offset = "0xE7A990", VA = "0x180E7B990")]
	public void UpdatePos(Vector2 anchoredPos)
	{
		this.root.anchoredPosition = anchoredPos;
	}

	// Token: 0x06001AB4 RID: 6836 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001AB4")]
	[Address(RVA = "0xE7B840", Offset = "0xE7A840", VA = "0x180E7B840")]
	public void UpdateArrowPos(UILabelHandler handler)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001AB5 RID: 6837 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001AB5")]
	[Address(RVA = "0xE7B6F0", Offset = "0xE7A6F0", VA = "0x180E7B6F0")]
	public void UpdateArrowPos(UIMagicStatsHandler handler)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001AB6 RID: 6838 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001AB6")]
	[Address(RVA = "0xE7B570", Offset = "0xE7A570", VA = "0x180E7B570")]
	private IEnumerator<float> ProcessFading(float value)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001AB7 RID: 6839 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001AB7")]
	[Address(RVA = "0xE7B5F0", Offset = "0xE7A5F0", VA = "0x180E7B5F0")]
	private void UpdateAlpha(float value)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001AB8 RID: 6840 RVA: 0x000414FC File Offset: 0x0003F6FC
	[Token(Token = "0x6001AB8")]
	[Address(RVA = "0x328C40", Offset = "0x327C40", VA = "0x180328C40")]
	public UINavigationEffect()
	{
	}

	// Token: 0x040024E0 RID: 9440
	[FieldOffset(Offset = "0x18")]
	[Token(Token = "0x40024E0")]
	[SerializeField]
	private RectTransform root;

	// Token: 0x040024E1 RID: 9441
	[FieldOffset(Offset = "0x20")]
	[Token(Token = "0x40024E1")]
	[SerializeField]
	private MaskableGraphic[] icons;

	// Token: 0x040024E2 RID: 9442
	[FieldOffset(Offset = "0x28")]
	[Token(Token = "0x40024E2")]
	private CoroutineHandle fadeProcessor;

	// Token: 0x040024E3 RID: 9443
	[FieldOffset(Offset = "0x2C")]
	[Token(Token = "0x40024E3")]
	private float alpha;
}
